@@ -6,7 +6,7 @@ use std::{
     env,
     fs::{self, create_dir_all, read_to_string, OpenOptions},
     io::{self, Write},
-    mem::{replace, take},
+    mem::take,
     path::Path,
     process::Command,
     rc::Rc,
@@ -17,6 +17,7 @@ use swc_common::{
     comments::SingleThreadedComments,
     errors::{Handler, HANDLER},
     sync::Lrc,
+    util::take::Take,
     FileName, SourceMap, DUMMY_SP,
 };
 use swc_ecma_ast::{Pat, *};
@@ -594,8 +595,7 @@ impl VisitMut for Normalizer {
         match node {
             PatOrExpr::Pat(pat) => match &mut **pat {
                 Pat::Expr(e) => {
-                    let e = replace(e, Box::new(Expr::Invalid(Invalid { span: DUMMY_SP })));
-                    *node = PatOrExpr::Expr(e);
+                    *node = PatOrExpr::Expr(e.take());
                 }
                 _ => {}
             },
